import { HttpInfo } from '../http/http';
import { Configuration, ConfigurationOptions } from '../configuration';
import { AssociationSpec } from '../models/AssociationSpec';
import { BatchInputPublicAssociationMultiArchive } from '../models/BatchInputPublicAssociationMultiArchive';
import { BatchInputPublicAssociationMultiPost } from '../models/BatchInputPublicAssociationMultiPost';
import { BatchInputPublicDefaultAssociationMultiPost } from '../models/BatchInputPublicDefaultAssociationMultiPost';
import { BatchInputPublicFetchAssociationsBatchRequest } from '../models/BatchInputPublicFetchAssociationsBatchRequest';
import { BatchResponseLabelsBetweenObjectPair } from '../models/BatchResponseLabelsBetweenObjectPair';
import { BatchResponseLabelsBetweenObjectPairWithErrors } from '../models/BatchResponseLabelsBetweenObjectPairWithErrors';
import { BatchResponsePublicAssociationMultiWithLabel } from '../models/BatchResponsePublicAssociationMultiWithLabel';
import { BatchResponsePublicAssociationMultiWithLabelWithErrors } from '../models/BatchResponsePublicAssociationMultiWithLabelWithErrors';
import { BatchResponsePublicDefaultAssociation } from '../models/BatchResponsePublicDefaultAssociation';
import { CollectionResponseMultiAssociatedObjectWithLabelForwardPaging } from '../models/CollectionResponseMultiAssociatedObjectWithLabelForwardPaging';
import { LabelsBetweenObjectPair } from '../models/LabelsBetweenObjectPair';
import { ReportCreationResponse } from '../models/ReportCreationResponse';
import { BasicApiRequestFactory, BasicApiResponseProcessor } from "../apis/BasicApi";
export interface BasicApiArchiveRequest {
    objectType: string;
    objectId: string;
    toObjectType: string;
    toObjectId: string;
}
export interface BasicApiCreateRequest {
    objectType: string;
    objectId: string;
    toObjectType: string;
    toObjectId: string;
    associationSpec: Array<AssociationSpec>;
}
export interface BasicApiCreateDefaultRequest {
    fromObjectType: string;
    fromObjectId: string;
    toObjectType: string;
    toObjectId: string;
}
export interface BasicApiGetPageRequest {
    objectType: string;
    objectId: string;
    toObjectType: string;
    after?: string;
    limit?: number;
}
export declare class ObjectBasicApi {
    private api;
    constructor(configuration: Configuration, requestFactory?: BasicApiRequestFactory, responseProcessor?: BasicApiResponseProcessor);
    archiveWithHttpInfo(param: BasicApiArchiveRequest, options?: ConfigurationOptions): Promise<HttpInfo<void>>;
    archive(param: BasicApiArchiveRequest, options?: ConfigurationOptions): Promise<void>;
    createWithHttpInfo(param: BasicApiCreateRequest, options?: ConfigurationOptions): Promise<HttpInfo<LabelsBetweenObjectPair>>;
    create(param: BasicApiCreateRequest, options?: ConfigurationOptions): Promise<LabelsBetweenObjectPair>;
    createDefaultWithHttpInfo(param: BasicApiCreateDefaultRequest, options?: ConfigurationOptions): Promise<HttpInfo<BatchResponsePublicDefaultAssociation>>;
    createDefault(param: BasicApiCreateDefaultRequest, options?: ConfigurationOptions): Promise<BatchResponsePublicDefaultAssociation>;
    getPageWithHttpInfo(param: BasicApiGetPageRequest, options?: ConfigurationOptions): Promise<HttpInfo<CollectionResponseMultiAssociatedObjectWithLabelForwardPaging>>;
    getPage(param: BasicApiGetPageRequest, options?: ConfigurationOptions): Promise<CollectionResponseMultiAssociatedObjectWithLabelForwardPaging>;
}
import { BatchApiRequestFactory, BatchApiResponseProcessor } from "../apis/BatchApi";
export interface BatchApiArchiveRequest {
    fromObjectType: string;
    toObjectType: string;
    batchInputPublicAssociationMultiArchive: BatchInputPublicAssociationMultiArchive;
}
export interface BatchApiArchiveLabelsRequest {
    fromObjectType: string;
    toObjectType: string;
    batchInputPublicAssociationMultiPost: BatchInputPublicAssociationMultiPost;
}
export interface BatchApiCreateRequest {
    fromObjectType: string;
    toObjectType: string;
    batchInputPublicAssociationMultiPost: BatchInputPublicAssociationMultiPost;
}
export interface BatchApiCreateDefaultRequest {
    fromObjectType: string;
    toObjectType: string;
    batchInputPublicDefaultAssociationMultiPost: BatchInputPublicDefaultAssociationMultiPost;
}
export interface BatchApiGetPageRequest {
    fromObjectType: string;
    toObjectType: string;
    batchInputPublicFetchAssociationsBatchRequest: BatchInputPublicFetchAssociationsBatchRequest;
}
export declare class ObjectBatchApi {
    private api;
    constructor(configuration: Configuration, requestFactory?: BatchApiRequestFactory, responseProcessor?: BatchApiResponseProcessor);
    archiveWithHttpInfo(param: BatchApiArchiveRequest, options?: ConfigurationOptions): Promise<HttpInfo<void>>;
    archive(param: BatchApiArchiveRequest, options?: ConfigurationOptions): Promise<void>;
    archiveLabelsWithHttpInfo(param: BatchApiArchiveLabelsRequest, options?: ConfigurationOptions): Promise<HttpInfo<void>>;
    archiveLabels(param: BatchApiArchiveLabelsRequest, options?: ConfigurationOptions): Promise<void>;
    createWithHttpInfo(param: BatchApiCreateRequest, options?: ConfigurationOptions): Promise<HttpInfo<BatchResponseLabelsBetweenObjectPairWithErrors | BatchResponseLabelsBetweenObjectPair>>;
    create(param: BatchApiCreateRequest, options?: ConfigurationOptions): Promise<BatchResponseLabelsBetweenObjectPairWithErrors | BatchResponseLabelsBetweenObjectPair>;
    createDefaultWithHttpInfo(param: BatchApiCreateDefaultRequest, options?: ConfigurationOptions): Promise<HttpInfo<BatchResponsePublicDefaultAssociation>>;
    createDefault(param: BatchApiCreateDefaultRequest, options?: ConfigurationOptions): Promise<BatchResponsePublicDefaultAssociation>;
    getPageWithHttpInfo(param: BatchApiGetPageRequest, options?: ConfigurationOptions): Promise<HttpInfo<BatchResponsePublicAssociationMultiWithLabel | BatchResponsePublicAssociationMultiWithLabelWithErrors>>;
    getPage(param: BatchApiGetPageRequest, options?: ConfigurationOptions): Promise<BatchResponsePublicAssociationMultiWithLabel | BatchResponsePublicAssociationMultiWithLabelWithErrors>;
}
import { ReportApiRequestFactory, ReportApiResponseProcessor } from "../apis/ReportApi";
export interface ReportApiRequestRequest {
    userId: number;
}
export declare class ObjectReportApi {
    private api;
    constructor(configuration: Configuration, requestFactory?: ReportApiRequestFactory, responseProcessor?: ReportApiResponseProcessor);
    requestWithHttpInfo(param: ReportApiRequestRequest, options?: ConfigurationOptions): Promise<HttpInfo<ReportCreationResponse>>;
    request(param: ReportApiRequestRequest, options?: ConfigurationOptions): Promise<ReportCreationResponse>;
}
