import { HttpInfo } from '../http/http';
import { Configuration, ConfigurationOptions } from '../configuration';
import { BatchInputTimelineEvent } from '../models/BatchInputTimelineEvent';
import { BatchResponseTimelineEventResponse } from '../models/BatchResponseTimelineEventResponse';
import { BatchResponseTimelineEventResponseWithErrors } from '../models/BatchResponseTimelineEventResponseWithErrors';
import { CollectionResponseTimelineEventTemplateNoPaging } from '../models/CollectionResponseTimelineEventTemplateNoPaging';
import { EventDetail } from '../models/EventDetail';
import { TimelineEvent } from '../models/TimelineEvent';
import { TimelineEventResponse } from '../models/TimelineEventResponse';
import { TimelineEventTemplate } from '../models/TimelineEventTemplate';
import { TimelineEventTemplateCreateRequest } from '../models/TimelineEventTemplateCreateRequest';
import { TimelineEventTemplateToken } from '../models/TimelineEventTemplateToken';
import { TimelineEventTemplateTokenUpdateRequest } from '../models/TimelineEventTemplateTokenUpdateRequest';
import { TimelineEventTemplateUpdateRequest } from '../models/TimelineEventTemplateUpdateRequest';
import { EventsApiRequestFactory, EventsApiResponseProcessor } from "../apis/EventsApi";
export interface EventsApiCreateRequest {
    timelineEvent: TimelineEvent;
}
export interface EventsApiCreateBatchRequest {
    batchInputTimelineEvent: BatchInputTimelineEvent;
}
export interface EventsApiGetByIdRequest {
    eventTemplateId: string;
    eventId: string;
}
export interface EventsApiGetDetailByIdRequest {
    eventTemplateId: string;
    eventId: string;
}
export interface EventsApiGetRenderByIdRequest {
    eventTemplateId: string;
    eventId: string;
    detail?: boolean;
}
export declare class ObjectEventsApi {
    private api;
    constructor(configuration: Configuration, requestFactory?: EventsApiRequestFactory, responseProcessor?: EventsApiResponseProcessor);
    createWithHttpInfo(param: EventsApiCreateRequest, options?: ConfigurationOptions): Promise<HttpInfo<TimelineEventResponse>>;
    create(param: EventsApiCreateRequest, options?: ConfigurationOptions): Promise<TimelineEventResponse>;
    createBatchWithHttpInfo(param: EventsApiCreateBatchRequest, options?: ConfigurationOptions): Promise<HttpInfo<BatchResponseTimelineEventResponse | void | BatchResponseTimelineEventResponseWithErrors>>;
    createBatch(param: EventsApiCreateBatchRequest, options?: ConfigurationOptions): Promise<BatchResponseTimelineEventResponse | void | BatchResponseTimelineEventResponseWithErrors>;
    getByIdWithHttpInfo(param: EventsApiGetByIdRequest, options?: ConfigurationOptions): Promise<HttpInfo<TimelineEventResponse>>;
    getById(param: EventsApiGetByIdRequest, options?: ConfigurationOptions): Promise<TimelineEventResponse>;
    getDetailByIdWithHttpInfo(param: EventsApiGetDetailByIdRequest, options?: ConfigurationOptions): Promise<HttpInfo<EventDetail>>;
    getDetailById(param: EventsApiGetDetailByIdRequest, options?: ConfigurationOptions): Promise<EventDetail>;
    getRenderByIdWithHttpInfo(param: EventsApiGetRenderByIdRequest, options?: ConfigurationOptions): Promise<HttpInfo<string>>;
    getRenderById(param: EventsApiGetRenderByIdRequest, options?: ConfigurationOptions): Promise<string>;
}
import { TemplatesApiRequestFactory, TemplatesApiResponseProcessor } from "../apis/TemplatesApi";
export interface TemplatesApiArchiveRequest {
    eventTemplateId: string;
    appId: number;
}
export interface TemplatesApiCreateRequest {
    appId: number;
    timelineEventTemplateCreateRequest: TimelineEventTemplateCreateRequest;
}
export interface TemplatesApiGetAllRequest {
    appId: number;
}
export interface TemplatesApiGetByIdRequest {
    eventTemplateId: string;
    appId: number;
}
export interface TemplatesApiUpdateRequest {
    eventTemplateId: string;
    appId: number;
    timelineEventTemplateUpdateRequest: TimelineEventTemplateUpdateRequest;
}
export declare class ObjectTemplatesApi {
    private api;
    constructor(configuration: Configuration, requestFactory?: TemplatesApiRequestFactory, responseProcessor?: TemplatesApiResponseProcessor);
    archiveWithHttpInfo(param: TemplatesApiArchiveRequest, options?: ConfigurationOptions): Promise<HttpInfo<void>>;
    archive(param: TemplatesApiArchiveRequest, options?: ConfigurationOptions): Promise<void>;
    createWithHttpInfo(param: TemplatesApiCreateRequest, options?: ConfigurationOptions): Promise<HttpInfo<TimelineEventTemplate>>;
    create(param: TemplatesApiCreateRequest, options?: ConfigurationOptions): Promise<TimelineEventTemplate>;
    getAllWithHttpInfo(param: TemplatesApiGetAllRequest, options?: ConfigurationOptions): Promise<HttpInfo<CollectionResponseTimelineEventTemplateNoPaging>>;
    getAll(param: TemplatesApiGetAllRequest, options?: ConfigurationOptions): Promise<CollectionResponseTimelineEventTemplateNoPaging>;
    getByIdWithHttpInfo(param: TemplatesApiGetByIdRequest, options?: ConfigurationOptions): Promise<HttpInfo<TimelineEventTemplate>>;
    getById(param: TemplatesApiGetByIdRequest, options?: ConfigurationOptions): Promise<TimelineEventTemplate>;
    updateWithHttpInfo(param: TemplatesApiUpdateRequest, options?: ConfigurationOptions): Promise<HttpInfo<TimelineEventTemplate>>;
    update(param: TemplatesApiUpdateRequest, options?: ConfigurationOptions): Promise<TimelineEventTemplate>;
}
import { TokensApiRequestFactory, TokensApiResponseProcessor } from "../apis/TokensApi";
export interface TokensApiArchiveRequest {
    eventTemplateId: string;
    tokenName: string;
    appId: number;
}
export interface TokensApiCreateRequest {
    eventTemplateId: string;
    appId: number;
    timelineEventTemplateToken: TimelineEventTemplateToken;
}
export interface TokensApiUpdateRequest {
    eventTemplateId: string;
    tokenName: string;
    appId: number;
    timelineEventTemplateTokenUpdateRequest: TimelineEventTemplateTokenUpdateRequest;
}
export declare class ObjectTokensApi {
    private api;
    constructor(configuration: Configuration, requestFactory?: TokensApiRequestFactory, responseProcessor?: TokensApiResponseProcessor);
    archiveWithHttpInfo(param: TokensApiArchiveRequest, options?: ConfigurationOptions): Promise<HttpInfo<void>>;
    archive(param: TokensApiArchiveRequest, options?: ConfigurationOptions): Promise<void>;
    createWithHttpInfo(param: TokensApiCreateRequest, options?: ConfigurationOptions): Promise<HttpInfo<TimelineEventTemplateToken>>;
    create(param: TokensApiCreateRequest, options?: ConfigurationOptions): Promise<TimelineEventTemplateToken>;
    updateWithHttpInfo(param: TokensApiUpdateRequest, options?: ConfigurationOptions): Promise<HttpInfo<TimelineEventTemplateToken>>;
    update(param: TokensApiUpdateRequest, options?: ConfigurationOptions): Promise<TimelineEventTemplateToken>;
}
