import { HttpFile, HttpInfo } from '../http/http';
import { Configuration, ConfigurationOptions } from '../configuration';
import { CollectionResponseFile } from '../models/CollectionResponseFile';
import { CollectionResponseFolder } from '../models/CollectionResponseFolder';
import { FileActionResponse } from '../models/FileActionResponse';
import { FileStat } from '../models/FileStat';
import { FileUpdateInput } from '../models/FileUpdateInput';
import { Folder } from '../models/Folder';
import { FolderActionResponse } from '../models/FolderActionResponse';
import { FolderInput } from '../models/FolderInput';
import { FolderUpdateInput } from '../models/FolderUpdateInput';
import { FolderUpdateInputWithId } from '../models/FolderUpdateInputWithId';
import { FolderUpdateTaskLocator } from '../models/FolderUpdateTaskLocator';
import { ImportFromUrlInput } from '../models/ImportFromUrlInput';
import { ImportFromUrlTaskLocator } from '../models/ImportFromUrlTaskLocator';
import { SignedUrl } from '../models/SignedUrl';
import { FilesApiRequestFactory, FilesApiResponseProcessor } from "../apis/FilesApi";
export interface FilesApiDeleteRequest {
    fileId: string;
}
export interface FilesApiArchiveRequest {
    fileId: string;
}
export interface FilesApiCheckImportRequest {
    taskId: string;
}
export interface FilesApiDoSearchRequest {
    properties?: Array<string>;
    after?: string;
    before?: string;
    limit?: number;
    sort?: Array<string>;
    ids?: Array<number>;
    idLte?: number;
    idGte?: number;
    createdAt?: Date;
    createdAtLte?: Date;
    createdAtGte?: Date;
    updatedAt?: Date;
    updatedAtLte?: Date;
    updatedAtGte?: Date;
    name?: string;
    path?: string;
    parentFolderIds?: Array<number>;
    size?: number;
    sizeLte?: number;
    sizeGte?: number;
    height?: number;
    heightLte?: number;
    heightGte?: number;
    width?: number;
    widthLte?: number;
    widthGte?: number;
    encoding?: string;
    type?: string;
    extension?: string;
    url?: string;
    isUsableInContent?: boolean;
    allowsAnonymousAccess?: boolean;
    fileMd5?: string;
    expiresAt?: Date;
    expiresAtLte?: Date;
    expiresAtGte?: Date;
}
export interface FilesApiGetByIdRequest {
    fileId: string;
    properties?: Array<string>;
}
export interface FilesApiGetMetadataRequest {
    path: string;
    properties?: Array<string>;
}
export interface FilesApiGetSignedUrlRequest {
    fileId: string;
    size?: 'thumb' | 'icon' | 'medium' | 'preview';
    expirationSeconds?: number;
    upscale?: boolean;
}
export interface FilesApiImportFromUrlRequest {
    importFromUrlInput: ImportFromUrlInput;
}
export interface FilesApiReplaceRequest {
    fileId: string;
    file?: HttpFile;
    charsetHunch?: string;
    options?: string;
}
export interface FilesApiUpdatePropertiesRequest {
    fileId: string;
    fileUpdateInput: FileUpdateInput;
}
export interface FilesApiUploadRequest {
    file?: HttpFile;
    folderId?: string;
    folderPath?: string;
    fileName?: string;
    charsetHunch?: string;
    options?: string;
}
export declare class ObjectFilesApi {
    private api;
    constructor(configuration: Configuration, requestFactory?: FilesApiRequestFactory, responseProcessor?: FilesApiResponseProcessor);
    _deleteWithHttpInfo(param: FilesApiDeleteRequest, options?: ConfigurationOptions): Promise<HttpInfo<void>>;
    _delete(param: FilesApiDeleteRequest, options?: ConfigurationOptions): Promise<void>;
    archiveWithHttpInfo(param: FilesApiArchiveRequest, options?: ConfigurationOptions): Promise<HttpInfo<void>>;
    archive(param: FilesApiArchiveRequest, options?: ConfigurationOptions): Promise<void>;
    checkImportWithHttpInfo(param: FilesApiCheckImportRequest, options?: ConfigurationOptions): Promise<HttpInfo<FileActionResponse>>;
    checkImport(param: FilesApiCheckImportRequest, options?: ConfigurationOptions): Promise<FileActionResponse>;
    doSearchWithHttpInfo(param?: FilesApiDoSearchRequest, options?: ConfigurationOptions): Promise<HttpInfo<CollectionResponseFile>>;
    doSearch(param?: FilesApiDoSearchRequest, options?: ConfigurationOptions): Promise<CollectionResponseFile>;
    getByIdWithHttpInfo(param: FilesApiGetByIdRequest, options?: ConfigurationOptions): Promise<HttpInfo<any>>;
    getById(param: FilesApiGetByIdRequest, options?: ConfigurationOptions): Promise<any>;
    getMetadataWithHttpInfo(param: FilesApiGetMetadataRequest, options?: ConfigurationOptions): Promise<HttpInfo<FileStat>>;
    getMetadata(param: FilesApiGetMetadataRequest, options?: ConfigurationOptions): Promise<FileStat>;
    getSignedUrlWithHttpInfo(param: FilesApiGetSignedUrlRequest, options?: ConfigurationOptions): Promise<HttpInfo<SignedUrl>>;
    getSignedUrl(param: FilesApiGetSignedUrlRequest, options?: ConfigurationOptions): Promise<SignedUrl>;
    importFromUrlWithHttpInfo(param: FilesApiImportFromUrlRequest, options?: ConfigurationOptions): Promise<HttpInfo<ImportFromUrlTaskLocator>>;
    importFromUrl(param: FilesApiImportFromUrlRequest, options?: ConfigurationOptions): Promise<ImportFromUrlTaskLocator>;
    replaceWithHttpInfo(param: FilesApiReplaceRequest, options?: ConfigurationOptions): Promise<HttpInfo<any>>;
    replace(param: FilesApiReplaceRequest, options?: ConfigurationOptions): Promise<any>;
    updatePropertiesWithHttpInfo(param: FilesApiUpdatePropertiesRequest, options?: ConfigurationOptions): Promise<HttpInfo<any>>;
    updateProperties(param: FilesApiUpdatePropertiesRequest, options?: ConfigurationOptions): Promise<any>;
    uploadWithHttpInfo(param?: FilesApiUploadRequest, options?: ConfigurationOptions): Promise<HttpInfo<any>>;
    upload(param?: FilesApiUploadRequest, options?: ConfigurationOptions): Promise<any>;
}
import { FoldersApiRequestFactory, FoldersApiResponseProcessor } from "../apis/FoldersApi";
export interface FoldersApiArchiveRequest {
    folderId: string;
}
export interface FoldersApiArchiveByPathRequest {
    folderPath: string;
}
export interface FoldersApiCheckUpdateStatusRequest {
    taskId: string;
}
export interface FoldersApiCreateRequest {
    folderInput: FolderInput;
}
export interface FoldersApiDoSearchRequest {
    properties?: Array<string>;
    after?: string;
    before?: string;
    limit?: number;
    sort?: Array<string>;
    ids?: Array<number>;
    idLte?: number;
    idGte?: number;
    createdAt?: Date;
    createdAtLte?: Date;
    createdAtGte?: Date;
    updatedAt?: Date;
    updatedAtLte?: Date;
    updatedAtGte?: Date;
    name?: string;
    path?: string;
    parentFolderIds?: Array<number>;
}
export interface FoldersApiGetByIdRequest {
    folderId: string;
    properties?: Array<string>;
}
export interface FoldersApiGetByPathRequest {
    folderPath: string;
    properties?: Array<string>;
}
export interface FoldersApiUpdatePropertiesRequest {
    folderId: string;
    folderUpdateInput: FolderUpdateInput;
}
export interface FoldersApiUpdatePropertiesRecursivelyRequest {
    folderUpdateInputWithId: FolderUpdateInputWithId;
}
export declare class ObjectFoldersApi {
    private api;
    constructor(configuration: Configuration, requestFactory?: FoldersApiRequestFactory, responseProcessor?: FoldersApiResponseProcessor);
    archiveWithHttpInfo(param: FoldersApiArchiveRequest, options?: ConfigurationOptions): Promise<HttpInfo<void>>;
    archive(param: FoldersApiArchiveRequest, options?: ConfigurationOptions): Promise<void>;
    archiveByPathWithHttpInfo(param: FoldersApiArchiveByPathRequest, options?: ConfigurationOptions): Promise<HttpInfo<void>>;
    archiveByPath(param: FoldersApiArchiveByPathRequest, options?: ConfigurationOptions): Promise<void>;
    checkUpdateStatusWithHttpInfo(param: FoldersApiCheckUpdateStatusRequest, options?: ConfigurationOptions): Promise<HttpInfo<FolderActionResponse>>;
    checkUpdateStatus(param: FoldersApiCheckUpdateStatusRequest, options?: ConfigurationOptions): Promise<FolderActionResponse>;
    createWithHttpInfo(param: FoldersApiCreateRequest, options?: ConfigurationOptions): Promise<HttpInfo<Folder>>;
    create(param: FoldersApiCreateRequest, options?: ConfigurationOptions): Promise<Folder>;
    doSearchWithHttpInfo(param?: FoldersApiDoSearchRequest, options?: ConfigurationOptions): Promise<HttpInfo<CollectionResponseFolder>>;
    doSearch(param?: FoldersApiDoSearchRequest, options?: ConfigurationOptions): Promise<CollectionResponseFolder>;
    getByIdWithHttpInfo(param: FoldersApiGetByIdRequest, options?: ConfigurationOptions): Promise<HttpInfo<Folder>>;
    getById(param: FoldersApiGetByIdRequest, options?: ConfigurationOptions): Promise<Folder>;
    getByPathWithHttpInfo(param: FoldersApiGetByPathRequest, options?: ConfigurationOptions): Promise<HttpInfo<Folder>>;
    getByPath(param: FoldersApiGetByPathRequest, options?: ConfigurationOptions): Promise<Folder>;
    updatePropertiesWithHttpInfo(param: FoldersApiUpdatePropertiesRequest, options?: ConfigurationOptions): Promise<HttpInfo<Folder>>;
    updateProperties(param: FoldersApiUpdatePropertiesRequest, options?: ConfigurationOptions): Promise<Folder>;
    updatePropertiesRecursivelyWithHttpInfo(param: FoldersApiUpdatePropertiesRecursivelyRequest, options?: ConfigurationOptions): Promise<HttpInfo<FolderUpdateTaskLocator>>;
    updatePropertiesRecursively(param: FoldersApiUpdatePropertiesRecursivelyRequest, options?: ConfigurationOptions): Promise<FolderUpdateTaskLocator>;
}
