import { HttpFile, HttpInfo } from '../http/http';
import { Configuration, ConfigurationOptions } from '../configuration';
import { Observable } from '../rxjsStub';
import { CollectionResponseFile } from '../models/CollectionResponseFile';
import { CollectionResponseFolder } from '../models/CollectionResponseFolder';
import { FileActionResponse } from '../models/FileActionResponse';
import { FileStat } from '../models/FileStat';
import { FileUpdateInput } from '../models/FileUpdateInput';
import { Folder } from '../models/Folder';
import { FolderActionResponse } from '../models/FolderActionResponse';
import { FolderInput } from '../models/FolderInput';
import { FolderUpdateInput } from '../models/FolderUpdateInput';
import { FolderUpdateInputWithId } from '../models/FolderUpdateInputWithId';
import { FolderUpdateTaskLocator } from '../models/FolderUpdateTaskLocator';
import { ImportFromUrlInput } from '../models/ImportFromUrlInput';
import { ImportFromUrlTaskLocator } from '../models/ImportFromUrlTaskLocator';
import { SignedUrl } from '../models/SignedUrl';
import { FilesApiRequestFactory, FilesApiResponseProcessor } from "../apis/FilesApi";
export declare class ObservableFilesApi {
    private requestFactory;
    private responseProcessor;
    private configuration;
    constructor(configuration: Configuration, requestFactory?: FilesApiRequestFactory, responseProcessor?: FilesApiResponseProcessor);
    _deleteWithHttpInfo(fileId: string, _options?: ConfigurationOptions): Observable<HttpInfo<void>>;
    _delete(fileId: string, _options?: ConfigurationOptions): Observable<void>;
    archiveWithHttpInfo(fileId: string, _options?: ConfigurationOptions): Observable<HttpInfo<void>>;
    archive(fileId: string, _options?: ConfigurationOptions): Observable<void>;
    checkImportWithHttpInfo(taskId: string, _options?: ConfigurationOptions): Observable<HttpInfo<FileActionResponse>>;
    checkImport(taskId: string, _options?: ConfigurationOptions): Observable<FileActionResponse>;
    doSearchWithHttpInfo(properties?: Array<string>, after?: string, before?: string, limit?: number, sort?: Array<string>, ids?: Array<number>, idLte?: number, idGte?: number, createdAt?: Date, createdAtLte?: Date, createdAtGte?: Date, updatedAt?: Date, updatedAtLte?: Date, updatedAtGte?: Date, name?: string, path?: string, parentFolderIds?: Array<number>, size?: number, sizeLte?: number, sizeGte?: number, height?: number, heightLte?: number, heightGte?: number, width?: number, widthLte?: number, widthGte?: number, encoding?: string, type?: string, extension?: string, url?: string, isUsableInContent?: boolean, allowsAnonymousAccess?: boolean, fileMd5?: string, expiresAt?: Date, expiresAtLte?: Date, expiresAtGte?: Date, _options?: ConfigurationOptions): Observable<HttpInfo<CollectionResponseFile>>;
    doSearch(properties?: Array<string>, after?: string, before?: string, limit?: number, sort?: Array<string>, ids?: Array<number>, idLte?: number, idGte?: number, createdAt?: Date, createdAtLte?: Date, createdAtGte?: Date, updatedAt?: Date, updatedAtLte?: Date, updatedAtGte?: Date, name?: string, path?: string, parentFolderIds?: Array<number>, size?: number, sizeLte?: number, sizeGte?: number, height?: number, heightLte?: number, heightGte?: number, width?: number, widthLte?: number, widthGte?: number, encoding?: string, type?: string, extension?: string, url?: string, isUsableInContent?: boolean, allowsAnonymousAccess?: boolean, fileMd5?: string, expiresAt?: Date, expiresAtLte?: Date, expiresAtGte?: Date, _options?: ConfigurationOptions): Observable<CollectionResponseFile>;
    getByIdWithHttpInfo(fileId: string, properties?: Array<string>, _options?: ConfigurationOptions): Observable<HttpInfo<any>>;
    getById(fileId: string, properties?: Array<string>, _options?: ConfigurationOptions): Observable<any>;
    getMetadataWithHttpInfo(path: string, properties?: Array<string>, _options?: ConfigurationOptions): Observable<HttpInfo<FileStat>>;
    getMetadata(path: string, properties?: Array<string>, _options?: ConfigurationOptions): Observable<FileStat>;
    getSignedUrlWithHttpInfo(fileId: string, size?: 'thumb' | 'icon' | 'medium' | 'preview', expirationSeconds?: number, upscale?: boolean, _options?: ConfigurationOptions): Observable<HttpInfo<SignedUrl>>;
    getSignedUrl(fileId: string, size?: 'thumb' | 'icon' | 'medium' | 'preview', expirationSeconds?: number, upscale?: boolean, _options?: ConfigurationOptions): Observable<SignedUrl>;
    importFromUrlWithHttpInfo(importFromUrlInput: ImportFromUrlInput, _options?: ConfigurationOptions): Observable<HttpInfo<ImportFromUrlTaskLocator>>;
    importFromUrl(importFromUrlInput: ImportFromUrlInput, _options?: ConfigurationOptions): Observable<ImportFromUrlTaskLocator>;
    replaceWithHttpInfo(fileId: string, file?: HttpFile, charsetHunch?: string, options?: string, _options?: ConfigurationOptions): Observable<HttpInfo<any>>;
    replace(fileId: string, file?: HttpFile, charsetHunch?: string, options?: string, _options?: ConfigurationOptions): Observable<any>;
    updatePropertiesWithHttpInfo(fileId: string, fileUpdateInput: FileUpdateInput, _options?: ConfigurationOptions): Observable<HttpInfo<any>>;
    updateProperties(fileId: string, fileUpdateInput: FileUpdateInput, _options?: ConfigurationOptions): Observable<any>;
    uploadWithHttpInfo(file?: HttpFile, folderId?: string, folderPath?: string, fileName?: string, charsetHunch?: string, options?: string, _options?: ConfigurationOptions): Observable<HttpInfo<any>>;
    upload(file?: HttpFile, folderId?: string, folderPath?: string, fileName?: string, charsetHunch?: string, options?: string, _options?: ConfigurationOptions): Observable<any>;
}
import { FoldersApiRequestFactory, FoldersApiResponseProcessor } from "../apis/FoldersApi";
export declare class ObservableFoldersApi {
    private requestFactory;
    private responseProcessor;
    private configuration;
    constructor(configuration: Configuration, requestFactory?: FoldersApiRequestFactory, responseProcessor?: FoldersApiResponseProcessor);
    archiveWithHttpInfo(folderId: string, _options?: ConfigurationOptions): Observable<HttpInfo<void>>;
    archive(folderId: string, _options?: ConfigurationOptions): Observable<void>;
    archiveByPathWithHttpInfo(folderPath: string, _options?: ConfigurationOptions): Observable<HttpInfo<void>>;
    archiveByPath(folderPath: string, _options?: ConfigurationOptions): Observable<void>;
    checkUpdateStatusWithHttpInfo(taskId: string, _options?: ConfigurationOptions): Observable<HttpInfo<FolderActionResponse>>;
    checkUpdateStatus(taskId: string, _options?: ConfigurationOptions): Observable<FolderActionResponse>;
    createWithHttpInfo(folderInput: FolderInput, _options?: ConfigurationOptions): Observable<HttpInfo<Folder>>;
    create(folderInput: FolderInput, _options?: ConfigurationOptions): Observable<Folder>;
    doSearchWithHttpInfo(properties?: Array<string>, after?: string, before?: string, limit?: number, sort?: Array<string>, ids?: Array<number>, idLte?: number, idGte?: number, createdAt?: Date, createdAtLte?: Date, createdAtGte?: Date, updatedAt?: Date, updatedAtLte?: Date, updatedAtGte?: Date, name?: string, path?: string, parentFolderIds?: Array<number>, _options?: ConfigurationOptions): Observable<HttpInfo<CollectionResponseFolder>>;
    doSearch(properties?: Array<string>, after?: string, before?: string, limit?: number, sort?: Array<string>, ids?: Array<number>, idLte?: number, idGte?: number, createdAt?: Date, createdAtLte?: Date, createdAtGte?: Date, updatedAt?: Date, updatedAtLte?: Date, updatedAtGte?: Date, name?: string, path?: string, parentFolderIds?: Array<number>, _options?: ConfigurationOptions): Observable<CollectionResponseFolder>;
    getByIdWithHttpInfo(folderId: string, properties?: Array<string>, _options?: ConfigurationOptions): Observable<HttpInfo<Folder>>;
    getById(folderId: string, properties?: Array<string>, _options?: ConfigurationOptions): Observable<Folder>;
    getByPathWithHttpInfo(folderPath: string, properties?: Array<string>, _options?: ConfigurationOptions): Observable<HttpInfo<Folder>>;
    getByPath(folderPath: string, properties?: Array<string>, _options?: ConfigurationOptions): Observable<Folder>;
    updatePropertiesWithHttpInfo(folderId: string, folderUpdateInput: FolderUpdateInput, _options?: ConfigurationOptions): Observable<HttpInfo<Folder>>;
    updateProperties(folderId: string, folderUpdateInput: FolderUpdateInput, _options?: ConfigurationOptions): Observable<Folder>;
    updatePropertiesRecursivelyWithHttpInfo(folderUpdateInputWithId: FolderUpdateInputWithId, _options?: ConfigurationOptions): Observable<HttpInfo<FolderUpdateTaskLocator>>;
    updatePropertiesRecursively(folderUpdateInputWithId: FolderUpdateInputWithId, _options?: ConfigurationOptions): Observable<FolderUpdateTaskLocator>;
}
